@@ -1117,13 +1117,12 @@ void ReadCddaMMC12 (unsigned char *p, long lSector, unsigned long SectorBurstVal
         scmd.target = global.target;
         scmd.cdb.g5_cdb.cmd = 0xBE;
         scmd.cdb.g5_cdb.lun = global.lun;
-        scmd.cdb.g5_cdb.res = 1 << 1; /* expected sector type field CDDA */
         scmd.cdb.g5_cdb.res = 0; /* expected sector type field ALL */
-        scmd.cdb.g5_cdb.res10 = 1 << 2; /* plus all subchannels */
-        scmd.cdb.g5_cdb.res10 = 1 ; /* plus all subchannels RAW */
+        scmd.cdb.g5_cdb.res10 = 1; /* plus all subchannels RAW */
         g5_cdbaddr(&scmd.cdb.g5_cdb, lSector);
         g5x_cdblen(&scmd.cdb.g5_cdb, SectorBurstVal);
-	scmd.cdb.g5_cdb.count[3] = 1 << 4 | 3 << 5 ;	/* User data  + all headers */
+	scmd.cdb.g5_cdb.count[3] = 1 << 4 | 3 << 5 ;    /* User data  + all headers */
+
 
         if (jes_verbose) fprintf(stderr, "\nReadMMC12 CDDA...");
   while (scsicmd("ReadCD MMC 12") < 0
